summaryrefslogtreecommitdiffstats
path: root/sys/boot/powerpc/ofw/conf.c
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>2000-10-16 19:58:32 +0000
committerobrien <obrien@FreeBSD.org>2000-10-16 19:58:32 +0000
commit17dc0cb9cb0356407bdc1038322380115351dc85 (patch)
tree3b82c52a954f8b1ae00a570748a009e47f2a89e9 /sys/boot/powerpc/ofw/conf.c
parent147049dcacda73ecaa5e47fe2dcbdc41a4b3a11f (diff)
downloadFreeBSD-src-17dc0cb9cb0356407bdc1038322380115351dc85.zip
FreeBSD-src-17dc0cb9cb0356407bdc1038322380115351dc85.tar.gz
Convert from the Alpha compontents to PowerPC ones.
Diffstat (limited to 'sys/boot/powerpc/ofw/conf.c')
-rw-r--r--sys/boot/powerpc/ofw/conf.c32
1 files changed, 18 insertions, 14 deletions
diff --git a/sys/boot/powerpc/ofw/conf.c b/sys/boot/powerpc/ofw/conf.c
index c1f9ea1..95a85f7 100644
--- a/sys/boot/powerpc/ofw/conf.c
+++ b/sys/boot/powerpc/ofw/conf.c
@@ -27,8 +27,9 @@
*/
#include <stand.h>
-#include "libalpha/libalpha.h"
-#ifdef LOADER_NET_SUPPORT
+#include "libofw.h"
+
+#if defined(LOADER_NET_SUPPORT)
#include "dev_net.h"
#endif
@@ -44,16 +45,17 @@
/* Exported for libstand */
struct devsw *devsw[] = {
#if defined(LOADER_DISK_SUPPORT) || defined(LOADER_CDROM_SUPPORT)
- &srmdisk,
+ &ofwdisk,
#endif
-#ifdef LOADER_NET_SUPPORT
- &netdev,
+#if defined(LOADER_NET_SUPPORT)
+ &ofwnet,
+ &ofwnet,
#endif
NULL
};
struct fs_ops *file_system[] = {
-#ifdef LOADER_DISK_SUPPORT
+#ifdef LOADER_UFS_SUPPORT
&ufs_fsops,
#endif
#ifdef LOADER_CDROM_SUPPORT
@@ -69,22 +71,24 @@ struct fs_ops *file_system[] = {
NULL
};
-#ifdef LOADER_NET_SUPPORT
+extern struct netif_driver of_net;
+
struct netif_driver *netif_drivers[] = {
- &srmnet,
+#ifdef LOADER_NET_SUPPORT
+ &of_net,
+#endif
NULL,
};
#endif
/* Exported for alpha only */
/*
* Sort formats so that those that can detect based on arguments
* rather than reading the file go first.
*/
-extern struct file_format alpha_elf;
+extern struct file_format powerpc_elf;
struct file_format *file_formats[] = {
- &alpha_elf,
+/* &powerpc_elf,*/
NULL
};
@@ -94,9 +98,9 @@ struct file_format *file_formats[] = {
* We don't prototype these in libalpha.h because they require
* data structures from bootstrap.h as well.
*/
-extern struct console promconsole;
+extern struct console ofwconsole;
struct console *consoles[] = {
- &promconsole,
+ &ofwconsole,
NULL
};
OpenPOWER on IntegriCloud
@@ -69,22 +71,24 @@ struct fs_ops *file_system[] = {
NULL,
};
-#endif
-/* Exported for alpha only */
+/* Exported for PowerPC only */
/*
* Sort formats so that those that can detect based on arguments